/*
 * Created on Mar 15, 2004
 * BodeMagPanel.java
 */
/* 
 * This  program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published  by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
 * General Public License for more details.
 *
 * You  should  have  received  a copy of the GNU General Public License
 * along  with  this  program;  if  not,  write  to  the  Free  Software
 * Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 */
package pzapplet;

import javax.swing.*;
import java.awt.*;
/**
 * Holds the axis labels, title and a BodeMagPlot.
 * 
 * @author Brian Williams
 *
 */
public class BodeMagPanel extends GraphPanel {

	private BodeMagPlot bodeMagPlot;
	private JLabel title = new JLabel("", SwingConstants.CENTER);
	private JLabel yAxisLabel = new JLabel();
	private JLabel xAxisLabel = new JLabel("", SwingConstants.CENTER);

	/**
	 * Creates a new BodeMagPanel
	 */
	public BodeMagPanel() {
		this.setup();
		this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
	}

	protected void setup() {
		//super.setup();
		this.setLabels();
		SpringLayout layout = new SpringLayout();
		this.setLayout(layout);
		bodeMagPlot = new BodeMagPlot();
		this.add(title);
		this.add(bodeMagPlot);
		this.add(yAxisLabel);
		this.add(xAxisLabel);

		// Constraints to put title bar along top
		layout.putConstraint(
			SpringLayout.NORTH,
			title,
			0,
			SpringLayout.NORTH,
			this);
		layout.putConstraint(
			SpringLayout.EAST,
			title,
			0,
			SpringLayout.EAST,
			this);
		layout.putConstraint(
			SpringLayout.WEST,
			title,
			0,
			SpringLayout.WEST,
			this);

		// Constraints to put y axis label on left
		layout.putConstraint(
			SpringLayout.NORTH,
			yAxisLabel,
			100,
			SpringLayout.SOUTH,
			title);
		layout.putConstraint(
			SpringLayout.EAST,
			yAxisLabel,
			-20,
			SpringLayout.WEST,
			bodeMagPlot);

		//Constraints to put x axis label on bottom
		layout.putConstraint(
			SpringLayout.NORTH,
			xAxisLabel,
			10,
			SpringLayout.SOUTH,
			bodeMagPlot);
		layout.putConstraint(
			SpringLayout.EAST,
			xAxisLabel,
			0,
			SpringLayout.EAST,
			this);
		layout.putConstraint(
			SpringLayout.WEST,
			xAxisLabel,
			0,
			SpringLayout.WEST,
			this);

		//Contraints to put graph along left side
		layout.putConstraint(
			SpringLayout.NORTH,
			bodeMagPlot,
			5,
			SpringLayout.SOUTH,
			title);
		layout.putConstraint(
			SpringLayout.EAST,
			bodeMagPlot,
			-100,
			SpringLayout.EAST,
			this);

	}
	private void setLabels() {
		title.setText("Magnitude vs Frequency");
		yAxisLabel.setText("Mag (dB)");
		xAxisLabel.setText("Frequency (rad/s)");

		title.setMaximumSize(
			new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
		yAxisLabel.setMaximumSize(
			new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
		xAxisLabel.setMaximumSize(
			new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
	}

	/* (non-Javadoc)
	 * @see pzapplet.GraphPanel#updateGraphics(pzapplet.LinearSystemHolder)
	 */
	public void updateGraphics(LinearSystemHolder sys) {
		FreqResponse[] freqs = sys.getAllFreqs();
		bodeMagPlot.graphFreqs(freqs);
	}
	public Dimension getPreferredSize() {
			return new Dimension(600, 250);
		}
		public Dimension getMinimumSize() {
			return new Dimension(600, 250);
		}
		public Dimension getMaximumSize() {
			return new Dimension(600, 250);
		}
}
