/*
 * Created on Feb 28, 2004
 * BodeMagPlot.java
 */
/* 
 * This  program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published  by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be  useful,  but
 * WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
 * General Public License for more details.
 *
 * You  should  have  received  a copy of the GNU General Public License
 * along  with  this  program;  if  not,  write  to  the  Free  Software
 * Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 */
package pzapplet;
import javax.swing.BorderFactory;
import java.awt.*;

/**
 * Graphs the magnitude plot of a full Bode plot.
 * 
 * @author Brian Williams
 *
 */
public class BodeMagPlot extends GraphPlot {

	/**
	 * Creates a new BodeMagPlot
	 */
	public BodeMagPlot() {
		super.setup();
		this.Y_SCALING_FACTOR = .8;
		this.Y_MIDDLE_VALUE = -40;
		this.height = 200;
		this.heightOverTwo = this.height / 2;
		this.width = 400;
		this.setLabels();
		this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		Graphics2D g2 = (Graphics2D)g.create();
		g2.setColor(Color.WHITE);
		g2.fillRect(0, 0, this.width, this.height);
		this.drawGridlines(g2);
		if (this.frequencyResponses != null) {
			for (int h = 0; h < this.frequencyResponses.length; h++) {
				FreqResponse frequency = this.frequencyResponses[h];
				Color freqColor = this.colorSelection[h % this.numOfColors];
				g2.setColor(freqColor);
				if (frequency != null) {
					double[] freqs = frequency.getFreqs();
					double[] mags = frequency.getMags();
					double low = (double)frequency.getLow();
					double high = (double)frequency.getHigh();
					int p1x = 0;
					int p1y = 0;
					int p2x = (int)Math.round(((double)this.width)*((Math.log(freqs[0])/Math.log(10)-low)/(high-low)));
					int p2y =
						(int)Math.round(
							(-mags[0] + this.Y_MIDDLE_VALUE)
								/ this.Y_SCALING_FACTOR)
							+ this.heightOverTwo;
					for (int i = 1; i < mags.length; i++) {
						p1x = p2x;
						p1y = p2y;
						p2x = (int)Math.round(((double)this.width)*((Math.log(freqs[i])/Math.log(10)-low)/(high-low)));
						p2y =
							(int)Math.round(
								(-mags[i] + this.Y_MIDDLE_VALUE)
									/ this.Y_SCALING_FACTOR)
								+ this.heightOverTwo;

						g2.drawLine(p1x, p1y, p2x, p2y);

					}
				}
			}
		}
		g2.dispose();
	}

	void drawGridlines(Graphics2D g2) {
		super.drawGridlines(g2);
		g2.setColor(Color.BLACK);
		g2.drawLine(0, this.height / 4, this.width, this.height / 4);
	}

	private void setLabels() {
		double yrange = this.height * this.Y_SCALING_FACTOR;
		int topInt = (int) (yrange * .25 + this.Y_MIDDLE_VALUE);
		int botInt = (int) (-yrange * .25 + this.Y_MIDDLE_VALUE);
		int midInt = this.Y_MIDDLE_VALUE;
		topLabel = "" + topInt;
		botLabel = "" + botInt;
		midLabel = "" + midInt;

		leftLabel = "1/10";
		centerLabel = "1";
		rightLabel = "10";
	}
}
