/*
 * Created on Mar 15, 2004
 * BodePhasePanel.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import javax.swing.*;
import java.awt.*;

/**
 * Holds axis labels, title and a BodePhasePlot.
 * 
 * 
 * @author Brian Williams
 *
 */
public class BodePhasePanel extends GraphPanel {

	// Variables to hold Bode phase plot and labels
	private BodePhasePlot bodePhasePlot;
	private JLabel title = new JLabel("", SwingConstants.CENTER);
	private JLabel yAxisLabel = new JLabel();
	private JLabel xAxisLabel = new JLabel("", SwingConstants.CENTER);

	/**
	 * Creates new BodePhasePanel
	 */
	public BodePhasePanel() {
		this.setup();
		this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
	}

	/**
	 * Overwritten setup() method from GraphPanel.
	 * 
	 * Specifies the labels and their arrangement within this.
	 */
	protected void setup() {
		//super.setup();
		this.setLabels();
		SpringLayout layout = new SpringLayout();
		this.setLayout(layout);
		bodePhasePlot = new BodePhasePlot();
		this.add(title);
		this.add(bodePhasePlot);
		this.add(yAxisLabel);
		this.add(xAxisLabel);

		// Constraints to put title bar along top
		layout.putConstraint(
			SpringLayout.NORTH,
			title,
			0,
			SpringLayout.NORTH,
			this);
		layout.putConstraint(
					SpringLayout.EAST,
					title,
					0,
					SpringLayout.EAST,
					this);
		layout.putConstraint(
			SpringLayout.WEST,
			title,
			0,
			SpringLayout.WEST,
			this);

		// Constraints to put y axis label on left
		layout.putConstraint(
			SpringLayout.NORTH,
			yAxisLabel,
			100,
			SpringLayout.SOUTH,
			title);
		layout.putConstraint(
			SpringLayout.EAST,
			yAxisLabel,
			-20,
			SpringLayout.WEST,
			bodePhasePlot);

		//Constraints to put x axis label on bottom
		layout.putConstraint(
			SpringLayout.NORTH,
			xAxisLabel,
			10,
			SpringLayout.SOUTH,
			bodePhasePlot);
		layout.putConstraint(
					SpringLayout.EAST,
					xAxisLabel,
					0,
					SpringLayout.EAST,
					this);
		layout.putConstraint(
			SpringLayout.WEST,
			xAxisLabel,
			0,
			SpringLayout.WEST,
			this);
		

		//Contraints to put graph along left side
		layout.putConstraint(
			SpringLayout.NORTH,
			bodePhasePlot,
			5,
			SpringLayout.SOUTH,
			title);
		layout.putConstraint(
			SpringLayout.EAST,
			bodePhasePlot,
			-100,
			SpringLayout.EAST,
			this);

	}
	
	// Assigns the labels of the plot and gives them the 
	// appropriate size for the SpringLayout to work correctly.
	private void setLabels() {
		title.setText("Phase vs Frequency");
		yAxisLabel.setText("Phase (Deg)");
		xAxisLabel.setText("Frequency (rad/s)");

		title.setMaximumSize(new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
		yAxisLabel.setMaximumSize(new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
		xAxisLabel.setMaximumSize(new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
	}

	/**
	 * Overwritten updateGraphics from GraphPanel.
	 * Specifically passes sys to the BodePhasePlot contained in
	 * this.
	 * 
	 * @param sys - LinearSystemHolder with data to plot.
	 */
	public void updateGraphics(LinearSystemHolder sys) {
		FreqResponse[] freqs = sys.getAllFreqs();
		bodePhasePlot.graphFreqs(freqs);
	}
	
	// Overwritten size methods to ensure the correct size.
	public Dimension getPreferredSize() {
		return new Dimension(600, 250);
	}
	public Dimension getMinimumSize() {
		return new Dimension(600, 250);
	}
	public Dimension getMaximumSize() {
		return new Dimension(600, 250);
	}

}
