/*
 * Created on Mar 13, 2004
 * BodePlotPanel.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import java.awt.*;

/**
 * Holds the two JPanel's of the Bode plot, magnitude and phase.
 * 
 * This class acts as a mediator between the two children panels
 * and its parent, forwarding the messages for updating and 
 * redrawing the child graphs.
 * 
 * @author Brian Williams
 * 
 *
 */
public class BodePlotPanel extends GraphPanel {
	
	// Variables to hold the two panels of the Bode Plot
	private BodeMagPanel bodeMag = new BodeMagPanel();
	private BodePhasePanel bodePhase = new BodePhasePanel();
	
	/**
	 * Creates a new BodePlotPanel.
	 */
	public BodePlotPanel() {
		this.setup();
	}
	
	/* (non-Javadoc)
	 * @see pzapplet.GraphPanel#setup()
	 */
	public void setup() {
		GridBagLayout gridbag = new GridBagLayout();
				GridBagConstraints c = new GridBagConstraints();
				this.setLayout(gridbag);
				c.gridwidth = GridBagConstraints.REMAINDER;
				gridbag.setConstraints(bodeMag, c);
				this.add(bodeMag);
				c.weightx = 0.0;
				gridbag.setConstraints(bodePhase, c);
				this.add(bodePhase);
				this.setOpaque(true);
				this.setBackground(Color.GRAY);
	}

	/**
	 * Updates itself and its children panels with new information
	 * passed in the sys variable.
	 * 
	 * @param sys - the LinearSystemHolder that contains information
	 * 		  about the plots that need to be graphed.
	 */
	public void updateGraphics(LinearSystemHolder sys) {
		bodeMag.updateGraphics(sys);
		bodePhase.updateGraphics(sys);
		repaint();
	}
	
	
	// Overwritten sized to ensure consistent viewing of the applet
	public Dimension getPreferredSize() {
		return new Dimension(600, 500);
	}
	public Dimension getMinimumSize() {
		return new Dimension(600, 500);
	}
	public Dimension getMaximumSize() {
		return new Dimension(600, 500);
	}
}
