/*
 * Created on Feb 15, 2004
 * Coord.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

/**
 * 
 *  This class represents a coordinate in a cartesian plane.
 * 
 * The coordinate has an x value and y value, which is normally
 * written as (x, y).  
 * 
 * This class provides a method for finding if Coord's are 
 * within a specified range of each other and finding the 
 * reflected point over the X axis.
 * 
 * @author Brian Williams
 *
 */
public class Coord {

	private int x;
	private int y;
	
	/**
	 * @param x - x value of the new Coord
	 * @param y - y value of the new Coord
	 * 
	 * Creates a Coord object that represents a coordinate
	 * in a cartesian plane (x, y).
	 * 
	 */
	public Coord(int x, int y) {
		this.x = x;
		this.y = y;
	}
	
	
	/**
	 * @return int x - The x value of this
	 */
	public int getX() {
		return x;
	}

	/**
	 * @return int y - The y value of this
	 */
	public int getY() {
		return y;
	}
	
	/**
	 * @param arg - The coord to compare to this
	 * @param range - The distance allowed between the two Coords
	 * @return true if the x and y values of each Coord are
	 * 		    independently within the value of range
	 */
	public boolean withinRangeOf(Coord arg, int range) {
		if (Math.abs(arg.getX() - this.x) <= range &&
			(Math.abs(arg.getY() - this.y)) <= range) {
			return true;
		}
		else return false;
	}
	
	/**
	 * @param arg - the Coord to compare to this
	 * @return true if the two Coord's refer to the same point
	 */
	public boolean equals(Coord arg) {
		if (arg.getX() == this.x && arg.getY() == this.y) {
			return true;
		}
		else {
			return false;
		}
	}
	
	/**
	 * @param height - the offset from the measurement of the
	 * 				   x-axis to the 0 of the drawing plane.
	 * 
	 * @return a new Coord that has the same x value, but a 
	 *    	   y-value that is the opposite of this
	 */
	public Coord getOpp(int height) {
		return new Coord(x, height - y);
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return "{"+x+", "+y+")";
	}	
}
