/*
 * Created on Mar 11, 2004
 * GraphPlot.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import javax.swing.JPanel;
import java.awt.*;

/**
 * Abstract class defining how a graph should be drawn.
 * 
 * @author Brian Williams
 *
 */
public abstract class GraphPlot extends JPanel {

	FreqResponse[] frequencyResponses;
	StepResponse[] stepResponses;

	double X_SCALING_FACTOR = 1.0;
	double Y_SCALING_FACTOR = 1.0;
	int X_MIDDLE_VALUE = 1;
	int Y_MIDDLE_VALUE = 1;

	final Color[] colorSelection = { Color.BLUE, Color.RED, Color.ORANGE };
	final int numOfColors = colorSelection.length;
	int height;

	int heightOverTwo;

	int width;

	int widthOverTwo;

	Color lineColor = new Color(14, 49, 60, 30);

	Font graphFont = new Font(null, 00, 10);

	String topLabel, midLabel, botLabel;
	String leftLabel, centerLabel, rightLabel;

	void setup() {
		frequencyResponses = null;
		height = -1;
		width = -1;
		this.setOpaque(true);
		this.setBackground(Color.GRAY);
	}

	/**
	 * Graphs the specific frequency responses to be plotted.
	 * 
	 * @param systems - The set of frequency response data to be
	 *  		 		graphed.
	 */
	public void graphFreqs(FreqResponse[] systems) {
		this.frequencyResponses = systems;
		repaint();
	}

	/**
	 * Graphs the specific steps responses to be plotted.
	 * 
	 * @param systems - The set of step response data to be
	 *  		 		graphed.
	 */
	public void graphSteps(StepResponse[] systems) {
		this.stepResponses = systems;
		repaint();
	}

	// Overwritten methods to ensure the size of each GraphPlot
	// is equal to the width and height the plot assumes it is
	// drawing on. This ensures the graph will never be cut off,
	// or draw smaller than its alloted space in the applet.
	public Dimension getPreferredSize() {
		return new Dimension(this.width, this.height);
	}
	public Dimension getMinimumSize() {
		return new Dimension(this.width, this.height);
	}
	public Dimension getMaximumSize() {
		return new Dimension(this.width, this.height);
	}

	/**
	 * Draws the standard set of 3 vertical and 3 horizontal graph
	 * lines.  Also draws labels at the bottom/left of each lines'
	 * intersection with the edge of the graph space.
	 * 
	 * Can be extended or overwritten to specify a different
	 * set of gridlines or additions to the default set.
	 * 
	 * @param g2 - graphics object being drawn on by caller
	 */
	void drawGridlines(Graphics2D g2) {
		g2.setColor(Color.BLACK);
		g2.setFont(graphFont);

		g2.drawString(leftLabel, this.width / 4 + 2, this.height - 2);
		g2.drawString(centerLabel, this.width / 2 + 2, this.height - 2);
		g2.drawString(rightLabel, this.width * 3 / 4 + 2, this.height - 2);

		g2.setColor(lineColor);
		g2.drawLine(this.width / 4, 0, this.width / 4, this.height);
		g2.drawLine(this.width / 2, 0, this.width / 2, this.height);
		g2.drawLine(this.width * 3 / 4, 0, this.width * 3 / 4, this.height);

		g2.setColor(lineColor);
		g2.drawLine(0, this.height * 3 / 4, this.width, this.height * 3 / 4);
		g2.drawLine(0, this.heightOverTwo, this.width, this.heightOverTwo);
		g2.drawLine(0, this.height / 4, this.width, this.height / 4);

		g2.setColor(Color.BLACK);
		g2.drawString(botLabel, 4, this.height * 3 / 4 + 10);
		g2.drawString(midLabel, 4, this.height / 2 + 10);
		g2.drawString(topLabel, 4, this.height / 4 + 10);
	}
}
