/*
 * Created on Feb 13, 2004
 * FreqAndStepResponse.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import java.util.*;

/**
 * 
	 * This Class contains all the LinearSystems to be graphed.  
	 * 
	 * Each LinearSystem object is a combination of a frequency and step
	 * response. 
 * @author Brian Williams
 *
 */
public class LinearSystemHolder {


	private Vector systems;

	/**
	 * Creates a new Frequency/StepResponse Response container.
	 * This class holds related Frequency and StepResponse Response pairs.
	 * 
	 * A LinearSystem can be represented by both or just one system response
	 * output, but for the purpose of keeping each system represented
	 * in a different object, they are all stored as pairs.
	 */
	public LinearSystemHolder() {
		systems = new Vector();
	}

	/**
	 * @param f - Frequency response of a system
	 * @param s - StepResponse response of a system
	 */
	public void addSystem(FreqResponse f, StepResponse s) {
		LinearSystem newPair = new LinearSystem(f,s);
		systems.add(newPair);
	}
	
	/**
	 * @param sys - A full LinearSystem
	 */
	public void addSystem(LinearSystem sys) {
		systems.add(sys);
	}

	/**
	 * @param f - Frequency response of a system
	 */
	public void addSystem(FreqResponse f) {
		this.addSystem(f, null);
	}
	
	/**
	 * @param s - StepResponse response of a system
	 */
	public void addSystem(StepResponse s) {
		this.addSystem(null, s);
	}

	/**
	 * @return A Vector of all Systems contained in this
	 */
	public Vector getAllSystems() {
		return systems;
	}
	
	/**
	 * Replaces the current Vector of systems with an empty vector
	 */
	public void deleteAllSystems() {
		systems = new Vector();
	}
	
	/**
	 * @return A Vector containing the Frequency response of all
	 * Systems of this
	 * 
	 * The Vector contains null for each LinearSystem with no frequency
	 * response specified.
	 */
	public FreqResponse[] getAllFreqs() {
		FreqResponse[] temp = new FreqResponse[systems.size()];
		for (int i = 0; i<temp.length; i++) {
			temp[i] = (((LinearSystem)systems.elementAt(i)).getFreq());
		}
		return temp;
	}
	
	/**
	 * @return A Vector containing the StepResponse response of all
	 * Systems of this
	 * 
	 * The Vector contains null for each LinearSystem with no step response
	 * specified.
	 */
	public StepResponse[] getAllSteps() {
		StepResponse[] temp = new StepResponse[systems.size()];
		for (int i = 0; i<systems.size(); i++) {
			temp[i] = (((LinearSystem)systems.elementAt(i)).getStep());
		}
		return temp;
	}
}
