/*
 * Created on Mar 16, 2004
 * NyquistPlot.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import javax.swing.*;
import java.awt.*;

/**
 * Draws the Nyquist Plot for one or many LinearSystems.
 * 
 * @author Brian Williams
 *
 */
public class NyquistPlot extends GraphPlot {

	/**
	 * Creates a new NyquistPlot
	 */
	public NyquistPlot() {
		super.setup();
		this.X_SCALING_FACTOR = .01;
		this.Y_SCALING_FACTOR = .01;
		this.X_MIDDLE_VALUE = 0;
		this.Y_MIDDLE_VALUE = 0;
		this.height = 400;
		this.heightOverTwo = this.height / 2;
		this.width = 400;
		this.widthOverTwo = this.width / 2;
		this.setLabels();
		this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
	}

	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		Graphics2D g2 = (Graphics2D)g.create();
		g2.setColor(Color.WHITE);
		g2.fillRect(0, 0, this.width, this.height);
		this.drawGridlines(g2);
		if (this.frequencyResponses != null) {
			for (int h = 0; h < this.frequencyResponses.length; h++) {
				FreqResponse frequency = this.frequencyResponses[h];
				Color freqColor = this.colorSelection[h % this.numOfColors];
				g2.setColor(freqColor);
				if (frequency != null) {
					double[] mags = frequency.getMags();
					double[] phases = frequency.getPhases();
					double mag1 = 0;
					int p1x = (int)mag1;  // No good reason
					int p1y = 0;
					double mag2 = Math.exp(mags[0] * Math.log(10.0) / 20);
					int p2x =
						(int) (Math
							.round(
								mag2
									* Math.cos(Math.toRadians(phases[0]))
									/ this.X_SCALING_FACTOR))
							+ this.widthOverTwo;
					int p2y =
						(int) (Math
							.round(
								mag2
									* Math.sin(Math.toRadians(phases[0]))
									/ this.Y_SCALING_FACTOR))
							+ this.heightOverTwo;

					for (int i = 1; i < mags.length; i++) {
						mag1 = mag2;
						p1x = p2x;
						p1y = p2y;
						mag2 =
							Math.exp(mags[i] * Math.log(10.0) / 20);
						p2x =
							(int) (Math
								.round(
									mag2
										* Math.cos(Math.toRadians(phases[i]))
										/ this.X_SCALING_FACTOR))
								+ this.widthOverTwo;
						p2y =
							(int) (Math
								.round(
									mag2
										* Math.sin(Math.toRadians(phases[i]))
										/ this.Y_SCALING_FACTOR))
								+ this.heightOverTwo;
						g2.setColor(Color.GREEN);
						g2.drawLine(p1x, p1y, p2x, p2y);
						g2.setColor(freqColor);
						g2.drawLine(p1x, -p1y + height, p2x, -p2y + height);
						

					}
				}
			}
		}
		g2.dispose();
	}

	void drawGridlines(Graphics2D g2) {
		super.drawGridlines(g2);
		g2.setColor(Color.DARK_GRAY);
		g2.drawLine(0, this.height / 2, this.width, this.height / 2);
		g2.drawLine(this.width * 2 / 4, 0, this.width * 2 / 4, this.height);
		g2.setColor(Color.RED);
		g2.drawLine(this.width / 4-1, this.heightOverTwo + 6, this.width/4-1,
				this.heightOverTwo-6);
		g2.drawLine(this.width / 4, this.heightOverTwo + 6, this.width/4,
						this.heightOverTwo-6);
		g2.drawLine(this.width / 4+1, this.heightOverTwo + 6, this.width/4+1,
						this.heightOverTwo-6);
		g2.drawLine(this.width / 4 + 6, this.heightOverTwo+1, this.width/4 -6,
						this.heightOverTwo+1);
		g2.drawLine(this.width / 4 + 6, this.heightOverTwo, this.width/4 -6,
								this.heightOverTwo);
		g2.drawLine(this.width / 4 + 6, this.heightOverTwo-1, this.width/4 -6,
								this.heightOverTwo-1);
	}

	private void setLabels() {
		double yrange = this.height * this.Y_SCALING_FACTOR;
		int topInt = (int) (yrange * .25 + this.Y_MIDDLE_VALUE);
		int botInt = (int) (-yrange * .25 + this.Y_MIDDLE_VALUE);
		int midInt = this.Y_MIDDLE_VALUE;
		topLabel = "" + topInt;
		botLabel = "" + botInt;
		midLabel = "" + midInt;

		double xrange = this.width * this.X_SCALING_FACTOR;
		int rightInt = (int) (xrange * .25 + this.X_MIDDLE_VALUE);
		int leftInt = (int) (-xrange * .25 + this.X_MIDDLE_VALUE);
		int centerInt = this.X_MIDDLE_VALUE;
		rightLabel = "" + rightInt;
		leftLabel = "" + leftInt;
		centerLabel = "" + centerInt;
	}
}
