/*
 * Created on Mar 13, 2004
 * PZButtons.java
 */ /* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import javax.swing.JPanel;
import javax.swing.*;
import java.util.Vector;
import java.awt.*;
import java.awt.event.*;

/**
 * 
 * This creates the buttons that change the mode of the applet.
 * 
 * 
 * The different modes are adding/deleting poles and zeros and 
	* dragging poles and zeros.  There's also a button for resetting the graph.  This also holds
	* This also holds the output text listing the current poles and zeros.
	* 
	* The buttons change the mode of the applet.  The mode determines what 
	* happens when clicking on the S-Plane graph.
 * 
 *  @author Brian Williams
 * 
 */
public class PZButtons extends JPanel {
	// Strings to use in labels
	private String addPoleLabel = "Add Pole";
	private String deleteLabel = "Delete Pole/Zero";
	private String addZeroLabel = "Add Zero";
	private String dragLabel = "Drag Pole/Zero";
	private String resetLabel = "Reset";

	//Buttons
	private JButton addZeroButton = new JButton(addZeroLabel);
	private JButton addPoleButton = new JButton(addPoleLabel);
	private JButton deleteButton = new JButton(deleteLabel);
	private JButton draggingButton = new JButton(dragLabel);
	private JButton resetButton = new JButton(resetLabel);

	// Text area and scroll pane
	private JTextArea outputField = new JTextArea(2, 0);
	private JScrollPane scrollPane =
		new JScrollPane(
			outputField,
			JScrollPane.VERTICAL_SCROLLBAR_NEVER,
			JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);

	// Reference to the applet creating the buttons
	private PoleZeroApplet pzApplet;

	// Size of the buttons frame
	private int height;
	private int width;

	/**
	 * @param pzApp - PoleZeroApplet reference to calling object
	 * 
	 * 
	 * Creates a new PZButtons.  pzApp must not be null
	 */
	public PZButtons(PoleZeroApplet pzApp) {
		this.setLayout(new BorderLayout());
		pzApplet = pzApp;
		height = 200;
		width = 400;
		setupPane();
	}

	//	Overwritten to set panel to fixed dimension
	public Dimension getPreferredSize() {
		return new Dimension(width, height);
	}
	public Dimension getMinimumSize() {
		return new Dimension(width, height);
	}
	public Dimension getMaximumSize() {
		return new Dimension(width, height);
	}

	// Method that creates the buttons/action listeners
	// Also creates the text panel for displaying poles and zeros
	private void setupPane() {
		addPoleButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				pzApplet.setMode("Poles");
			}
		});
		addZeroButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				pzApplet.setMode("Zeros");
			}
		});
		deleteButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				pzApplet.setMode("Delete");
			}
		});
		draggingButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				pzApplet.setMode("Dragging");
			}
		});
		resetButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				pzApplet.reset();
			}
		});
		outputField.setEditable(false);
		// Creates a small panel to hold the two "add" buttons
		JPanel testPanel = new JPanel();
		testPanel.setLayout(new GridLayout(0, 2, 2, 2));
		testPanel.add(addPoleButton);
		testPanel.add(addZeroButton);

		// Adds that small panel to the other buttons
		JPanel testPanel2 = new JPanel();
		testPanel2.setLayout(new GridLayout(0, 2, 2, 2));
		testPanel2.add(testPanel);
		testPanel2.add(deleteButton);
		testPanel2.add(draggingButton);
		testPanel2.add(resetButton);

		// Sets the scroll panel below the buttons
		this.add(testPanel2, BorderLayout.CENTER);
		this.add(scrollPane, BorderLayout.SOUTH);
		this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
	}

	// Creates the strings for lists of poles and zeros
	private String vectorsToCoordinates() {
		Vector zeros = pzApplet.getZeros();
		Vector poles = pzApplet.getPoles();
		String output = "Zeros: ";
		for (int i = 0; i < zeros.size(); i++) {
			Coord zero = (Coord)zeros.get(i);
			double x = zero.getX();
			double y = zero.getY();
			x = (Math.round(x - 100.0)) / 10.0;
			y = (Math.round(y - 100.0)) / 10.0;
			if (y >= 0.0) {
				output += "( " + x;
				if (y != 0.0) {
					output += "  " + y + "j";
				}
				output += " ) ";
			}
		}
		output += "\n";
		output += "Poles: ";
		for (int i = 0; i < poles.size(); i++) {
			Coord pole = (Coord)poles.get(i);
			double x = pole.getX();
			double y = pole.getY();
			x = (Math.round(x - 100.0)) / 10.0;
			y = (Math.round(y - 100.0)) / 10.0;
			if (y >= 0.0) {
				output += "( " + x;
				if (y != 0.0) {
					output += "  " + y + "j";
				}
				output += " ) ";
			}
		}
		return output;
	}

	/**
	 * 
	 * Updates the graphics of this.
	 * Includes changing the labels if any highlighting is needed and
	 * changing the text of the pole/zero list panel.
	 *  
	 */
	public void updateGraphics() {
		if (pzApplet != null && pzApplet.getMode() != null) {
			outputField.setText(vectorsToCoordinates());
			highlightLabels(pzApplet.getMode());
		}
		repaint();
	}

	// Changes the labels on the buttons to reflect the "Active" mode
	private void highlightLabels(String mode) {
		if (mode == "Zeros") {
			addZeroButton.setLabel(
				"<html><font size='4' color=#0000FF>Add Zero</font></html>");
		} else {
			addZeroButton.setLabel("Add Zero");
		}
		if (mode == "Poles") {
			addPoleButton.setLabel(
				"<html><font size='4' color=#0000FF>Add Pole</font></html>");
		} else {
			addPoleButton.setLabel("Add Pole");
		}
		if (mode == "Delete") {
			deleteButton.setLabel(
				"<html><font size='4' color=#0000FF>Delete Pole/Zero</font></html>");
		} else {
			deleteButton.setLabel("Delete Pole/Zero");
		}
		if (mode == "Dragging") {
			draggingButton.setLabel(
				"<html><font size='4' color=#0000FF>Drag Pole/Zero</font></html>");
		} else {
			draggingButton.setLabel("Drag Pole/Zero");
		}
	}

}
