/*
 * Created on Feb 13, 2004
 * PoleZeroApplet.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import java.awt.*;

import javax.swing.*;
import java.util.Vector;
import ORG.netlib.math.complex.*;

/**
 * The root class for the Pole Zero Applet.
 * 
 * @author Mr Bill
 *
 */
public class PoleZeroApplet extends JApplet {

	// Active "mode" for adding/deleting poles/zeros
	private String mode;

	// Variables to hold for poles/zeros
	private Vector poles;
	private Vector zeros;

	// Holds multiple systems, allows for expansion to multiple graphs
	private LinearSystemHolder foSystems;

	// Holds the three panels, the S-Plane, Buttons, and Output
	private PZSPlaneGraph pzGraph = new PZSPlaneGraph(this);
	private PZButtons pzButtons = new PZButtons(this);
	private PZOutputGraphs pzOutputGraphs = new PZOutputGraphs(this);

	// Reduces calls to this.getContentPane();
	private Container contentPane = this.getContentPane();

	
	public void addPolePair(Coord x, int height) {
		poles.add(x);
		if (x.getY() != height/2) 
			poles.add(x.getOpp(height));
		updateGraphics(true);
	}
	public void addZeroPair(Coord x, int height) {
		zeros.add(x);
		if (x.getY() != height/2)
			zeros.add(x.getOpp(height));
		updateGraphics(true);
	}

	public void deletePolePair(Coord arg, int height, boolean repaint) {
		Coord argOpp = arg.getOpp(height);
		for (int i = 0; i < poles.size(); i++) {
			Coord pole = (Coord)poles.get(i);
			if (pole.equals(arg)) {
				poles.remove(i);
				break;
			}
		}
		if (arg.getY() != height/2) {
			for (int i = 0; i < poles.size(); i++) {
				Coord pole = (Coord)poles.get(i);
				if (pole.equals(argOpp)) {
					poles.remove(i);
					break;
				}
			}
		}

		if (repaint)
			updateGraphics(true);
	}

	public void deleteZeroPair(Coord arg, int height, boolean repaint) {
		Coord argOpp = arg.getOpp(height);

		for (int i = 0; i < zeros.size(); i++) {
			Coord zero = (Coord)zeros.get(i);
			if (zero.equals(arg)) {
				zeros.remove(i);
				break;
			}
		}
		if (arg.getY() != height/2) {
			for (int i = 0; i < zeros.size(); i++) {
				Coord zero = (Coord)zeros.get(i);
				if (zero.equals(argOpp)) {
					zeros.remove(i);
					break;
				}
			}
		}

		if (repaint) {
			this.updateGraphics(true);
		}
	}

	/**
	 * @return mode - String representing the current mode
	 */
	public String getMode() {
		return mode;
	}

	/**
	 * @return poles - Vector containing all pole Coords
	 */
	public Vector getPoles() {
		return poles;
	}

	/**
	 * @return zeros - Vector containing all zero Coords
	 */
	public Vector getZeros() {
		return zeros;
	}

	// Tries to set the look and feel to the users system
	private void setupLookAndFeel() {
		try {
			UIManager.setLookAndFeel(
				UIManager.getCrossPlatformLookAndFeelClassName());
		} catch (Exception e) {
			System.out.println("Could not set look and feel");
		}
	}

	
	/* 
	 * Creates the Applet!
	 */
	public void init() {
		setupLookAndFeel();
		setupVariables();
		setupFrame();
	}

	// No idea how this works :-)  Don't know if it even does anything...
	public void start() {
		updateGraphics(true);
	}

	// Initializes the poles, zeros and system holder, sets initial mode
	private void setupVariables() {
		poles = new Vector();
		zeros = new Vector();
		foSystems = new LinearSystemHolder();
		mode = "Poles";
	}

	//  Creates the entire applet frame layout
	private void setupFrame() {
		Dimension size = new Dimension(
			pzButtons.getWidth()+pzGraph.getWidth()+pzOutputGraphs.getWidth(), 
			pzButtons.getHeight()+pzGraph.getHeight()+pzOutputGraphs.getHeight());
		this.setSize(600, 730);  // Just for testing
		
		JPanel panel = new JPanel(new BorderLayout());
		panel.setSize(size);
		panel.add(pzButtons, BorderLayout.EAST);
		panel.add(pzGraph, BorderLayout.WEST);
		panel.add(pzOutputGraphs, BorderLayout.SOUTH);
		contentPane.add(panel);
	}

	/**
	 * @param string - String to set mode, must be "Poles", "Zeros", 
	 * "Delete" or "Dragging"
	 */
	public void setMode(String string) {
		mode = string;
		this.updateGraphics(false);
	}

	// Creates an array of Complex numbers from Coord Vector
	private Complex[] CoordsToComplex(Vector coords) {
		Complex[] complex = new Complex[coords.size()];
		for (int i = 0; i < coords.size(); i++) {
			Coord pole = (Coord)coords.get(i);
			double x = pole.getX();
			double y = pole.getY();
			x = (Math.round(x - 100.0)) / 10.0;
			y = (Math.round(y - 100.0)) / 10.0;
			complex[i] = new Complex(x, y);
		}
		return complex;
	}

	
	/**
	 * Resets the Applet to its starting state, except for the mode
	 */
	public void reset() {
		poles = new Vector();
		zeros = new Vector();
		this.updateGraphics(true);
	}

	// Updates graphics and may not update the output if not necessary
	private void updateGraphics(boolean updateAll) {
		if (updateAll) {
			updateOutputGraphics();
		}
		pzButtons.updateGraphics();
		pzGraph.updateGraphics();
	}

	/**
	 * Updates the entire applet: s-plane, buttons, and output graphs
	 */
	public void updateApplet() {
		updateGraphics(true);
	}

	// Updates just the output graphs
	private void updateOutputGraphics() {
		//Vector test = foSystems.getAllSystems();
		foSystems.deleteAllSystems();
		foSystems.addSystem(
			new FreqResponse(CoordsToComplex(zeros), CoordsToComplex(poles)),
			new StepResponse(CoordsToComplex(zeros), CoordsToComplex(poles)));
		//if (!test.isEmpty())
		//	foSystems.addSystem((LinearSystem)test.firstElement());
		pzOutputGraphs.updateGraphics(foSystems);	
	}
}
