/*
 * Created on Apr 12, 2004
 * StepResponsePlot.java
 *//* 
* This  program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published  by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
*
* This program is distributed in the hope that it will be  useful,  but
* WITHOUT   ANY   WARRANTY;   without  even  the  implied  warranty  of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR  PURPOSE.   See  the  GNU
* General Public License for more details.
*
* You  should  have  received  a copy of the GNU General Public License
* along  with  this  program;  if  not,  write  to  the  Free  Software
* Foundation,  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA.
*/
package pzapplet;

import java.awt.*;
import javax.swing.*;

/**
 * Draws the plot of one or many LinearSystems.
 * 
 * @author Brian Williams
 *
 */
public class StepResponsePlot extends GraphPlot {

	/**
	 * Creates a new StepResponsePlot.
	 */
	public StepResponsePlot() {
		super.setup();
		this.X_SCALING_FACTOR = .01;
		this.Y_SCALING_FACTOR = .01;
		this.X_MIDDLE_VALUE = 2;
		this.Y_MIDDLE_VALUE = 1;
		this.height = 400;
		this.heightOverTwo = this.height / 2;
		this.width = 400;
		this.widthOverTwo = this.width / 2;
		this.setLabels();
		this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
	}

	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		Graphics2D g2 = (Graphics2D)g.create();
		g2.setColor(Color.WHITE);
		g2.fillRect(0, 0, this.width, this.height);
		this.drawGridlines(g2);
		if (this.stepResponses != null) {
			for (int h = 0; h < this.stepResponses.length; h++) {
				StepResponse step = this.stepResponses[h];
				Color freqColor = this.colorSelection[h % this.numOfColors];
				g2.setColor(freqColor);
				if (step.getErrorMsg()) {
					g2.drawString("ERROR: More Zeros than Poles.", 130, 170);
				}
				else if (step != null) {
					double[] data = step.getStepResponseData();

					int p1x = 0;
					int p1y = 0;
					int p2x =
						0;
					int p2y =
						(int)Math.round(
							(-data[0] + this.Y_MIDDLE_VALUE)
								/ this.Y_SCALING_FACTOR)
							+ this.heightOverTwo;

					for (int i = 1; i < data.length; i++) {
						p1x = p2x;
						p1y = p2y;

						p2x =
							i;
						p2y =
							(int)Math.round(
								(-data[i] + this.Y_MIDDLE_VALUE)
									/ this.Y_SCALING_FACTOR)
								+ this.heightOverTwo;

						g2.drawLine(p1x, p1y, p2x, p2y);
					}

					g2.dispose();
				}
			}
		}
	}

	void drawGridlines(Graphics2D g2) {
		super.drawGridlines(g2);
	}

	private void setLabels() {
		double yrange = this.height * this.Y_SCALING_FACTOR;
		int topInt = (int) (yrange * .25 + this.Y_MIDDLE_VALUE);
		int botInt = (int) (-yrange * .25 + this.Y_MIDDLE_VALUE);
		int midInt = this.Y_MIDDLE_VALUE;
		topLabel = "" + topInt;
		botLabel = "" + botInt;
		midLabel = "" + midInt;

		double xrange = this.width * this.X_SCALING_FACTOR;
		int rightInt = (int) (xrange * .25 + this.X_MIDDLE_VALUE);
		int leftInt = (int) (-xrange * .25 + this.X_MIDDLE_VALUE);
		int centerInt = this.X_MIDDLE_VALUE;
		rightLabel = "" + rightInt;
		leftLabel = "" + leftInt;
		centerLabel = "" + centerInt;
	}
}
